<form id="payzen_auto_submit_form" name="payzen_auto_submit_form" action="{{ payzen_submit_url }}" method="post">
  {{ form }}
</form>

<script type="text/javascript">
  document.forms["payzen_auto_submit_form"].submit()
</script>
